Description Usage Arguments Examples
Export data frame to LaTeX file
1 2 3 4 |
df |
table data |
file |
file name |
eol |
named vector of end-of-line strings |
footer |
string to be added after the bottom rule |
col.types |
string of column types |
full.size |
use tabularx if TRUE, else tabular |
demo |
create demo latex document (ready-to-compile), disables full.size export |
outer.rules |
add top and bottom rule automatically (otherwise: specify in eol parameter) |
filter.columns |
remove column names starting with a dot |
split.column |
create multiple tables based on the distinct values of this column, NA entries correspond to global headers/footers. |
1 2 3 4 | ## Not run:
ltx.write(mtcars, "mtcars.tex")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.